==> react-text-templates-1.0.3.tgz: package/index.es.js <==
/** @license databyss.org v1.0.3
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';

var escape = function escape(str) {
  return typeof str === 'string' ? str.replace(new RegExp('"', 'g'), '&quot;') : String(str);
};

export default (function (template, tokenDict) {
  // "extract" tokens in template by splitting on token pattern
  //   so "you have {COUNT} friends in common with {NAME} "
  //   becomes ['you have', '{COUNT}', 'friends in common with', '{NAME}']
  var templateParts = template.split(/(\{.+?\})/); // loop over templateParts and replace tokens with corresponding values
  //   from tokenDict

  var keyRegex = /\{(.+?)\}/;
  var jsxKeyCount = 0;
  var foundJsx = false;
  var renderedParts = templateParts.reduce(function (arr, part) {
    if (!part.length) {
      return arr;
    }

    if (!part.match(keyRegex)) {
      // part is plain string.
      return arr.concat(part);
    }

    var key = part.match(keyRegex)[1];
    var val = tokenDict[key]; // if the value is a react element, add a key and concat

    if (React.isValidElement(val)) {
      foundJsx = true;
      var jsxval = React.cloneElement(val, {
        key: jsxKeyCount
      });
      jsxKeyCount += 1;
      return arr.concat(jsxval);
    } // otherwise, treat it as a literal


    return arr.concat(escape(val));
  }, []);

  if (foundJsx) {
    // join consecutive string elements
    //   so ['you have ', '50', ' friends in common with', <Link href="/joe">Joe</Link>]
    //   becomes ['you have 50 friends in common with', <Link href="/joe">Joe</Link>]
    var strAccum = '';
    return renderedParts.reduce(function (arr, part) {
      if (typeof part !== 'string') {
        if (!strAccum.length) {
          return arr.concat(part);
        }

        var flushedStr = strAccum;
        strAccum = '';
        return arr.concat([flushedStr, part]);
      }

      strAccum = strAccum.concat(part);
      return arr;
    }, []).concat(strAccum);
  }

  return renderedParts.join('');
});

==> react-text-templates-1.0.5.tgz: package/index.es.js <==
/** @license databyss.org v1.0.5
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from 'react';

var escape = function escape(str) {
  return typeof str === 'string' ? str.replace(new RegExp('"', 'g'), '&quot;') : String(str);
};

export default (function (template, tokenDict) {
  // "extract" tokens in template by splitting on token pattern
  //   so "you have {COUNT} friends in common with {NAME} "
  //   becomes ['you have', '{COUNT}', 'friends in common with', '{NAME}']
  var templateParts = template.split(/(\{.+?\})/); // loop over templateParts and replace tokens with corresponding values
  //   from tokenDict

  var keyRegex = /\{(.+?)\}/;
  var jsxKeyCount = 0;
  var foundJsx = false;
  var renderedParts = templateParts.reduce(function (arr, part) {
    if (!part.length) {
      return arr;
    }

    if (!part.match(keyRegex)) {
      // part is plain string.
      return arr.concat(part);
    }

    var key = part.match(keyRegex)[1];
    var val = tokenDict[key]; // if key isn't in the dict, leave the string alone

    if (!val) {
      return arr.concat(part);
    } // if the value is a react element, add a key and concat


    if (React.isValidElement(val)) {
      foundJsx = true;
      var jsxval = React.cloneElement(val, {
        key: jsxKeyCount
      });
      jsxKeyCount += 1;
      return arr.concat(jsxval);
    } // otherwise, treat it as a literal


    return arr.concat(escape(val));
  }, []);

  if (foundJsx) {
    // join consecutive string elements
    //   so ['you have ', '50', ' friends in common with', <Link href="/joe">Joe</Link>]
    //   becomes ['you have 50 friends in common with', <Link href="/joe">Joe</Link>]
    var strAccum = '';
    return renderedParts.reduce(function (arr, part) {
      if (typeof part !== 'string') {
        if (!strAccum.length) {
          return arr.concat(part);
        }

        var flushedStr = strAccum;
        strAccum = '';
        return arr.concat([flushedStr, part]);
      }

      strAccum = strAccum.concat(part);
      return arr;
    }, []).concat(strAccum);
  }

  return renderedParts.join('');
});
